summaryrefslogtreecommitdiffstats
path: root/kivio/kiviopart/config/kivio_config.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-16 09:56:31 -0600
committerTimothy Pearson <[email protected]>2011-12-16 09:56:31 -0600
commitc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (patch)
tree1ee1912ac4bb966475f0db0f2a78678661b4b4a5 /kivio/kiviopart/config/kivio_config.h
parent94844816550ad672ccfcdc25659c625546239998 (diff)
downloadkoffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.tar.gz
koffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 94844816550ad672ccfcdc25659c625546239998.
Diffstat (limited to 'kivio/kiviopart/config/kivio_config.h')
-rw-r--r--kivio/kiviopart/config/kivio_config.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kivio/kiviopart/config/kivio_config.h b/kivio/kiviopart/config/kivio_config.h
index 651ec121..b4df785a 100644
--- a/kivio/kiviopart/config/kivio_config.h
+++ b/kivio/kiviopart/config/kivio_config.h
@@ -34,12 +34,12 @@ namespace Kivio {
{
public:
/**
* Set the default page layout
*/
- static void setDefaultPageLayout(const KoPageLayout& layout);
+ static void setDefaultPageLayout(const KoPageLayout& tqlayout);
/**
* Get the default page layout
*/
static KoPageLayout defaultPageLayout();
@@ -34,12 +34,12 @@ namespace Kivio {
public:
/**
- * Set the default page layout
+ * Set the default page tqlayout
*/
@@ -34,12 +34,12 @@ namespace Kivio {
/**
- * Get the default page layout
+ * Get the default page tqlayout
*/
static KoPageLayout defaultPageLayout();